@@ -23,7 +23,7 @@ OUT_NODE1=$(mktemp /tmp/node1.XXXXXX)
 PORT_NODE1=3000
 #DB1="-W /tmp/node1 -D sled"
 #DB1="-W /tmp/node1 -D sneakers"
-$DIR/../target/$TARGET/dtnd -d -j5s -i0 -w $PORT_NODE1 -C mtcp:2342 -e incoming -r epidemic -n node1 -s mtcp://127.0.0.1:4223/node2 $DB1 $STATUS_REPORTS 2>&1 &> $OUT_NODE1 &
+$DIR/../target/$TARGET/dtnd -d -j5s -i0 -w $PORT_NODE1 -C tcp:2342 -e incoming -r epidemic -n node1 -s tcp://127.0.0.1:4223/node2 $DB1 $STATUS_REPORTS 2>&1 &> $OUT_NODE1 &
 PID_NODE1=$!
 echo node1 pid: $PID_NODE1
 echo node1 out: $OUT_NODE1
@@ -34,10 +34,10 @@ OUT_NODE2=$(mktemp /tmp/node2.XXXXXX)
 PORT_NODE2=3001
 #DB2="-W /tmp/node2 -D sled"
 #DB2="-W /tmp/node2 -D sneakers"
-$DIR/../target/$TARGET/dtnd -d -j5s -i0 -w $PORT_NODE2 -C mtcp:4223 -e incoming -r epidemic \
+$DIR/../target/$TARGET/dtnd -d -j5s -i0 -w $PORT_NODE2 -C tcp:4223 -e incoming -r epidemic \
     -n node2 \
-    -s mtcp://127.0.0.1:2342/node1 \
-    -s mtcp://127.0.0.1:2432/node3 \
+    -s tcp://127.0.0.1:2342/node1 \
+    -s tcp://127.0.0.1:2432/node3 \
     $DB2 2>&1 &> $OUT_NODE2 &
 PID_NODE2=$!
 echo node2 pid: $PID_NODE2
@@ -48,7 +48,7 @@ OUT_NODE3=$(mktemp /tmp/node3.XXXXXX)
 PORT_NODE3=3002
 #DB3="-W /tmp/node3 -D sled"
 #DB3="-W /tmp/node3 -D sneakers"
-$DIR/../target/$TARGET/dtnd -d -j5s -i0 -w $PORT_NODE3 -C mtcp:2432 -e incoming -r epidemic -n node3 -s mtcp://127.0.0.1:4223/node2 $DB3 $STATUS_REPORTS 2>&1 &> $OUT_NODE3 &
+$DIR/../target/$TARGET/dtnd -d -j5s -i0 -w $PORT_NODE3 -C tcp:2432 -e incoming -r epidemic -n node3 -s tcp://127.0.0.1:4223/node2 $DB3 $STATUS_REPORTS 2>&1 &> $OUT_NODE3 &
 PID_NODE3=$!
 echo node3 pid: $PID_NODE3
 echo node3 out: $OUT_NODE3
